@@ -692,20 +692,23 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                 for listener in loadbalancer.listeners:
                     status_listener = self._ovn_helper.listener_create(
                         self._get_listener_request_info(listener))
-                    status[constants.LISTENERS].append(status_listener)
+                    status[constants.LISTENERS].append(
+                        status_listener[constants.LISTENERS][0])
             if not isinstance(loadbalancer.pools, o_datamodels.UnsetType):
                 status[constants.POOLS] = []
                 for pool in loadbalancer.pools:
                     status_pool = self._ovn_helper.pool_create(
                         self._get_pool_request_info(pool))
-                    status[constants.POOLS].append(status_pool)
+                    status[constants.POOLS].append(
+                        status_pool[constants.POOLS][0])
                     for member in pool.members:
                         status[constants.MEMBERS] = []
                         if not member.subnet_id:
                             member.subnet_id = loadbalancer.vip_subnet_id
                         status_member = self._ovn_helper.member_create(
                             self._get_member_request_info(member))
-                        status[constants.MEMBERS].append(status_member)
+                        status[constants.MEMBERS].append(
+                            status_member[constants.MEMBERS][0])
                     if pool.healthmonitor is not None and not isinstance(
                             pool.healthmonitor, o_datamodels.UnsetType):
                         status[constants.HEALTHMONITORS] = []
@@ -717,7 +720,8 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                             status_hm = self._ovn_helper.hm_create(
                                 self._get_healthmonitor_request_info(
                                     pool.healthmonitor))
-                            status[constants.HEALTHMONITORS].append(status_hm)
+                            status[constants.HEALTHMONITORS].append(
+                                status_hm[constants.HEALTHMONITORS][0])
             self._ovn_helper._update_status_to_octavia(status)
         else:
             # Load Balancer found, check LB and listener/pool/member/hms
@@ -819,7 +823,7 @@ class OvnProviderDriver(driver_base.ProviderDriver):
         if fips:
             neutron_fip = fips[0].floating_ip_address
             if not vip_lsp:
-                LOG.warn(
+                LOG.warning(
                     "Logic Switch Port not found for port "
                     f"{loadbalancer.vip_port_id}. "
                     "Skip sync FIP for loadbalancer "
@@ -828,7 +832,7 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                     "first to sync OVN DB with Neutron DB.")
                 return
             if lsp_fip != neutron_fip:
-                LOG.warn(
+                LOG.warning(
                     "Floating IP not consistent between Logic Switch "
                     f"Port and Neutron. Found FIP {lsp_fip} "
                     f"in LSP {vip_lsp.name}, but we have {neutron_fip} from "
@@ -841,10 +845,10 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                 vip_lp=vip_lsp, fip=lsp_fip,
                 action=ovn_const.REQ_INFO_ACTION_SYNC)
         else:
-            LOG.warn("Floating IP not found for loadbalancer "
-                     f"{loadbalancer.loadbalancer_id}")
+            LOG.warning("Floating IP not found for loadbalancer "
+                        f"{loadbalancer.loadbalancer_id}")
             if lsp_fip:
-                LOG.warn(
+                LOG.warning(
                     "Floating IP not consistent between Logic Switch "
                     f"Port and Neutron. Found FIP {lsp_fip} configured "
                     f"in LSP {vip_lsp.name}, but no FIP configured from "
